@@ -34,7 +34,7 @@ package App::Dochazka::REST;
 
 use 5.012;
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use App::CELL qw( $CELL $log $meta $core $site );
 use App::Dochazka::REST::ConnBank qw( $dbix_conn );
@@ -58,11 +58,11 @@ App::Dochazka::REST - Dochazka REST server
 
 =head1 VERSION
 
-Version 0.492
+Version 0.493
 
 =cut
 
-our $VERSION = '0.492';
+our $VERSION = '0.493';
 
 
 =head2 Development status
